-- The destination table has id, parent_id, child_id, ordering.
-- In an ElementPath, the child ID is the element ID, and its immediate parent
-- is the last item in the array (path[array_length(path, 1)]).
-- We can safely ditch the rest of the array as the parent will have its own paths
-- with its own parents as last items.
-- We also ignore empty paths, used to represent top-level elements.
-- This uses DISTINCT ON because when the parent has two paths, the child will have
-- two paths with the same direct parent.  These two paths should have the same
-- ordering, but this is not actually enforced by any constraint.  ORDER BY is used
-- because DISTINCT ON requires it.
SELECT
    DISTINCT ON (path.path[array_length(path.path, 1)], path.element_id)
    path.id,
    path.path[array_length(path.path, 1)],
    path.element_id,
    path.ordering
FROM documents_elementpath path
INNER JOIN documents_element element ON (path.element_id = element.id)
WHERE element.corpus_id = '{corpus_id}'::uuid
AND path.path <> ARRAY[]::uuid[]
ORDER BY path.path[array_length(path.path, 1)], path.element_id
