from django.contrib import admin
from enumfields.admin import EnumFieldListFilter

from arkindex.project.admin import ArchivedListFilter
from arkindex.training.models import Dataset, DatasetSet, MetricKey, MetricValue, Model, ModelVersion


class ModelAdmin(admin.ModelAdmin):
    list_display = ("name", "created", "archived")
    list_filter = (ArchivedListFilter, )
    search_fields = ("name", "description", )
    fields = ("name", "description", "public", "archived", "compatible_workers")


class ModelVersionAdmin(admin.ModelAdmin):
    list_display = ("id", "model", "tag", "size", "state")
    list_filter = ("model__name", ("state", EnumFieldListFilter), )
    fields = ("model", "parent", "description", "state", "tag", "hash", "archive_hash", "size", "configuration",)
    readonly_fields = ("hash", "archive_hash", "size", )


class MetricValueInline(admin.StackedInline):
    model = MetricValue
    readonly_fields = ("value", "step")


class MetricKeyAdmin(admin.ModelAdmin):
    list_display = ("name", "model_version")
    fields = ("name", "mode", "model_version")
    list_filter = ("model_version__model",)
    inlines = [MetricValueInline, ]


class DatasetSetInLine(admin.StackedInline):
    model = DatasetSet


class DatasetAdmin(admin.ModelAdmin):
    list_display = ("name", "corpus", "state")
    list_filter = (("state", EnumFieldListFilter), "corpus")
    search_fields = ("name", "description")
    fields = ("id", "name", "created", "updated", "description", "corpus", "creator", "task")
    readonly_fields = ("id", "created", "updated", "task")
    inlines = [DatasetSetInLine, ]


admin.site.register(Model, ModelAdmin)
admin.site.register(ModelVersion, ModelVersionAdmin)
admin.site.register(MetricKey, MetricKeyAdmin)
admin.site.register(Dataset, DatasetAdmin)
